'use strict';

exports.__esModule = true;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _FormLabel = require('@material-ui/core/FormLabel');

var _FormLabel2 = _interopRequireDefault(_FormLabel);

var _FormGroup = require('@material-ui/core/FormGroup');

var _FormGroup2 = _interopRequireDefault(_FormGroup);

var _FormControl = require('@material-ui/core/FormControl');

var _FormControl2 = _interopRequireDefault(_FormControl);

var _FormControlLabel = require('@material-ui/core/FormControlLabel');

var _FormControlLabel2 = _interopRequireDefault(_FormControlLabel);

var _Checkbox = require('@material-ui/core/Checkbox');

var _Checkbox2 = _interopRequireDefault(_Checkbox);

var _arrayUtils = require('../../utils/arrayUtils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function CheckboxesGroupWidget(props) {
    function selectValue(value, selected, all) {
        var at = all.indexOf(value);
        var updated = selected.slice(0, at).concat(value, selected.slice(at));
        // As inserting values at predefined index positions doesn't work with empty
        // arrays, we need to reorder the updated selection to match the initial order
        return Array.from(updated).sort(function (a, b) {
            return all.indexOf(a) > all.indexOf(b);
        });
    }

    function deselectValue(value, selected) {
        return selected.filter(function (v) {
            return v !== value;
        });
    }

    var label = props.label,
        value = props.value,
        readonly = props.readonly,
        disabled = props.disabled,
        autofocus = props.autofocus,
        onBlur = props.onBlur,
        onFocus = props.onFocus,
        options = props.options,
        _onChange = props.onChange,
        schema = props.schema,
        formContext = props.formContext,
        registry = props.registry,
        otherProps = _objectWithoutProperties(props, ['label', 'value', 'readonly', 'disabled', 'autofocus', 'onBlur', 'onFocus', 'options', 'onChange', 'schema', 'formContext', 'registry']);

    var title = schema.title;
    var enumOptions = options.enumOptions,
        inline = options.inline;


    return _react2.default.createElement(
        _FormControl2.default,
        { component: 'fieldset' },
        _react2.default.createElement(
            _FormLabel2.default,
            { component: 'legend' },
            label || title
        ),
        _react2.default.createElement(
            _FormGroup2.default,
            null,
            enumOptions.map(function (option, index) {
                var checked = value && value.indexOf(option.value) !== -1;

                return _react2.default.createElement(_FormControlLabel2.default, {
                    key: index,
                    disabled: schema.disabled || readonly,
                    value: option.value,
                    label: option.label,
                    control: _react2.default.createElement(_Checkbox2.default, {
                        checked: checked,
                        onChange: function onChange(event) {
                            var all = enumOptions.map(function (_ref) {
                                var value = _ref.value;
                                return value;
                            });
                            var newValue = event.target.checked ? selectValue(option.value, value, all) : deselectValue(option.value, value);

                            _onChange(newValue);
                        },
                        value: (0, _arrayUtils.transformArrayToString)(value)
                    })
                });
            })
        )
    );
}

CheckboxesGroupWidget.defaultProps = {
    autofocus: false,
    options: {
        inline: false
    }
};

CheckboxesGroupWidget.propTypes = process.env.NODE_ENV !== "production" ? {
    schema: _propTypes2.default.object.isRequired,
    id: _propTypes2.default.string.isRequired,
    options: _propTypes2.default.shape({
        enumOptions: _propTypes2.default.array,
        inline: _propTypes2.default.bool
    }).isRequired,
    value: _propTypes2.default.any,
    required: _propTypes2.default.bool,
    readonly: _propTypes2.default.bool,
    disabled: _propTypes2.default.bool,
    multiple: _propTypes2.default.bool,
    autofocus: _propTypes2.default.bool,
    onChange: _propTypes2.default.func
} : {};

exports.default = CheckboxesGroupWidget;
module.exports = exports['default'];